@@ -4,10 +4,27 @@ from huscy.projects.models import Membership
 
 class IsProjectCoordinator(BasePermission):
     def has_permission(self, request, view):
+        if request.user.is_superuser:
+            return True
+
         return Membership.objects.filter(project=view.project, user=request.user,
                                          is_coordinator=True).exists()
 
 
+class UpdatePrincipalInvestigatorPermission(BasePermission):
+    def has_permission(self, request, view):
+        return bool(request.user and request.user.is_authenticated)
+
+    def has_object_permission(self, request, view, project):
+        if bool(request.user and request.user.is_authenticated):
+            if request.user.is_superuser:
+                return True
+
+            return Membership.objects.filter(project=project, user=request.user,
+                                             is_coordinator=True).exists()
+        return False
+
+
 class IsProjectMember(BasePermission):
     def has_permission(self, request, view):
         return Membership.objects.filter(project=view.project, user=request.user).exists()
@@ -17,13 +34,16 @@ class ProjectPermission(BasePermission):
     def has_permission(self, request, view):
         return True
 
-    def has_object_permission(self, request, view, obj):
+    def has_object_permission(self, request, view, project):
+        if request.method in SAFE_METHODS:
+            return True
+
         if request.method == 'DELETE':
             permission = 'projects.delete_project'
         else:
             permission = 'projects.change_project'
 
-        return (request.user.has_perm(permission) or request.user.has_perm(permission, obj))
+        return (request.user.has_perm(permission) or request.user.has_perm(permission, project))
 
 
 class ReadOnly(BasePermission):
