@@ -69,6 +69,16 @@ def get_research_units():
     return ResearchUnit.objects.all()
 
 
+def set_principal_investigator(project, user):
+    if not Membership.objects.filter(project=project, user=user, is_coordinator=True).exists():
+        raise ValueError('Only project members who are coordinators can become '
+                         'principal investigators.')
+
+    project.principal_investigator = user
+    project.save(update_fields=['principal_investigator'])
+    return project
+
+
 def update_membership(membership, is_coordinator, has_write_permission):
     if is_coordinator or has_write_permission:
         assign_perm('change_project', membership.user, membership.project)
@@ -77,3 +87,11 @@ def update_membership(membership, is_coordinator, has_write_permission):
     membership.is_coordinator = is_coordinator
     membership.save()
     return membership
+
+
+def update_project(project, local_id=None, title=None, description=None):
+    project.description = description or project.description
+    project.local_id = local_id or project.local_id
+    project.title = title or project.title
+    project.save(update_fields=['description', 'local_id', 'title'])
+    return project
